==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/FieldLevelEncryptionProfileEncryptionEntitiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class FieldLevelEncryptionProfileEncryptionEntitiesArgs(
    public val items: Output<List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs =
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs.builder()
            .items(
                items?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FieldLevelEncryptionProfileEncryptionEntitiesArgs].
 */
@PulumiTagMarker
public class FieldLevelEncryptionProfileEncryptionEntitiesArgsBuilder internal constructor() {
    private var items: Output<List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>? = null

    /**
     * @param value
     */
    @JvmName("rabejgjvxllwiajn")
    public suspend
    fun items(`value`: Output<List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>) {
        this.items = value
    }

    @JvmName("ssvydfynlmrqyuwy")
    public suspend fun items(
        vararg
        values: Output<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>,
    ) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("chhnnsmqcxnhfjff")
    public suspend
    fun items(values: List<Output<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ctaarddjtupkemip")
    public suspend fun items(`value`: List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ouattapahsnigkyj")
    public suspend
    fun items(argument: List<suspend FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("yjkgxxgigvodquks")
    public suspend fun items(
        vararg
        argument: suspend FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ulgwrrcovgmvbfdi")
    public suspend
    fun items(argument: suspend FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("qujmvvyulhgmtmti")
    public suspend fun items(vararg values: FieldLevelEncryptionProfileEncryptionEntitiesItemArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): FieldLevelEncryptionProfileEncryptionEntitiesArgs =
        FieldLevelEncryptionProfileEncryptionEntitiesArgs(
            items = items,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/FieldLevelEncryptionProfileEncryptionEntitiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class FieldLevelEncryptionProfileEncryptionEntitiesArgs(
    public val items: Output<List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs =
        com.pulumi.aws.cloudfront.inputs.FieldLevelEncryptionProfileEncryptionEntitiesArgs.builder()
            .items(
                items?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FieldLevelEncryptionProfileEncryptionEntitiesArgs].
 */
@PulumiTagMarker
public class FieldLevelEncryptionProfileEncryptionEntitiesArgsBuilder internal constructor() {
    private var items: Output<List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>? = null

    /**
     * @param value
     */
    @JvmName("cynccruqwlsookrd")
    public suspend fun items(`value`: Output<List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>) {
        this.items = value
    }

    @JvmName("pnvfkwsuiajkunlh")
    public suspend fun items(vararg values: Output<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("xoftqlcbpwjgvbid")
    public suspend fun items(values: List<Output<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("mfrcvltmsslxcnva")
    public suspend fun items(`value`: List<FieldLevelEncryptionProfileEncryptionEntitiesItemArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("fcpngvhmayhikhfo")
    public suspend fun items(argument: List<suspend FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kteqtuoboxtankiq")
    public suspend fun items(vararg argument: suspend FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument
     */
    @JvmName("podieakqeiqcwwxd")
    public suspend fun items(argument: suspend FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                FieldLevelEncryptionProfileEncryptionEntitiesItemArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("mlyagsnbluryxdcg")
    public suspend fun items(vararg values: FieldLevelEncryptionProfileEncryptionEntitiesItemArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): FieldLevelEncryptionProfileEncryptionEntitiesArgs =
        FieldLevelEncryptionProfileEncryptionEntitiesArgs(
            items = items,
        )
}
